@@ -6,7 +6,7 @@ from ..base import *
 # For the record, we can't import settings from production module because a syslogger is
 # configured there.
 
-BROKER_URL = "amqp://{% if RABBITMQ_USERNAME and RABBITMQ_PASSWORD %}{{ RABBITMQ_USERNAME }}:{{ RABBITMQ_PASSWORD }}@{% endif %}{{ RABBITMQ_HOST }}:5672"
+BROKER_URL = "redis://{% if REDIS_USERNAME and REDIS_PASSWORD %}{{ REDIS_USERNAME }}:{{ REDIS_PASSWORD }}@{% endif %}{{ REDIS_HOST }}:{{ REDIS_PORT }}"
 
 JWT_SECRET_KEY = "{{ JWT_COMMON_SECRET_KEY }}"
 JWT_ISSUER = "{{ JWT_COMMON_ISSUER }}"
